==> skrooge_1.2.0.orig.tar.bz2: skrooge-1.2.0/plugins/applet/account/accountskroogoid.h <==
/***************************************************************************
 *   Copyright (C) 2010 by SIDDHARTH SHARMA siddharth.kde@gmail.com        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/

#ifndef ACCOUNTSKROOGOID_H
#define ACCOUNTSKROOGOID_H
/** @file
* This file is Plasma Applet for Account Skroogoid
*
* @author Siddharth SHARMA
*/
#include <Plasma/Applet>
#include <Plasma/Label>
#include <qgraphicslinearlayout.h>
#include <qsignalmapper.h>

class SKGDocumentBank;
/**
* Class AccountSkroogoid
*/
class AccountSkroogoid : public Plasma::Applet
{
    Q_OBJECT

public:
    /**
     * Default Constructor
     */
    AccountSkroogoid(QObject* parent, const QVariantList& args);

    /**
    * Default Destructor
    */
    ~AccountSkroogoid();

    /**
     * Reimplemented from Plasma::Applet
     */
    virtual void init();

private Q_SLOTS:
    /**
     * Opens a new tab with the given account
     * @param accountName The name of the account
     */
    void openAccountTab(QString accountName);

    /**
     * Fetch data from the specified source
     */
    void dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData);

private:
    /**
     * The current Skrooge document
     */
    SKGDocumentBank* doc;

    /**
     * QGraphicsLinearLayout layout for adding items
     */
    QGraphicsLinearLayout* widgetLayout;

    /**
     * The signal mapper, used to open the account tab
     */
    QSignalMapper* signalMapper;
};

/**
  * For exporting skroogoid as a registered Plasma Applet
  */
K_EXPORT_PLASMA_APPLET(accountskroogoid, AccountSkroogoid)

#endif

==> skrooge-1.6.0.tar.bz2: skrooge-1.6.0/plugins/applet/account/accountskroogoid.h <==
/***************************************************************************
 *   Copyright (C) 2010 by SIDDHARTH SHARMA siddharth.kde@gmail.com        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/

#ifndef ACCOUNTSKROOGOID_H
#define ACCOUNTSKROOGOID_H
/** @file
* This file is Plasma Applet for Account Skroogoid
*
* @author Siddharth SHARMA
*/
#include <Plasma/Applet>
#include <Plasma/Label>
#include <qgraphicslinearlayout.h>
#include <qsignalmapper.h>

class SKGDocumentBank;
/**
* Class AccountSkroogoid
*/
class AccountSkroogoid : public Plasma::Applet
{
    Q_OBJECT

public:
    /**
     * Default Constructor
     */
    explicit AccountSkroogoid(QObject* parent, const QVariantList& args);

    /**
    * Default Destructor
    */
    ~AccountSkroogoid();

    /**
     * Reimplemented from Plasma::Applet
     */
    virtual void init();

private Q_SLOTS:
    /**
     * Opens a new tab with the given account
     * @param accountName The name of the account
     */
    void openAccountTab(QString accountName);

    /**
     * Fetch data from the specified source
     */
    void dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData);

private:
    /**
     * The current Skrooge document
     */
    SKGDocumentBank* doc;

    /**
     * QGraphicsLinearLayout layout for adding items
     */
    QGraphicsLinearLayout* widgetLayout;

    /**
     * The signal mapper, used to open the account tab
     */
    QSignalMapper* signalMapper;
};

/**
  * For exporting skroogoid as a registered Plasma Applet
  */
K_EXPORT_PLASMA_APPLET(accountskroogoid, AccountSkroogoid)

#endif
